/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Copyright (c) 2021 MediaTek Inc.
 * Author: Jianjiao Zeng <jianjiao.zeng@mediatek.com>
 */

#ifndef _DTS_IOMMU_PORT_MT6789_H_
#define _DTS_IOMMU_PORT_MT6789_H_

#include <dt-bindings/memory/mtk-memory-port.h>

/* table id must be the same as mtk_iommu.h */
#define MM_TAB					(0)
#define APU_TAB					(1)

/* iova region definition */
#define NORMAL_DOM				(0)
#define VDEC_DOM                                (1)
#define CAMMDP_DOM				(2)

/*
 * domain 0: display: larb0, larb1.
 * domain 1: codec: larb4, larb7.
 * domain 2: CAM and MDP: larb2, larb9, larb13, larb14, larb16,
 *           larb17, larb19, larb20.
 *
 * larb 0/1/2/4/7/9/13/14/16/17/19/20 is use
 * larb 3/5/6/8/10/11/12/15/18 is null.
 */

/*********************************************************/
/* larb0 -- 4 */
#define M4U_PORT_L0_DISP_POSTMASK0		MTK_M4U_PORT_ID(MM_TAB, NORMAL_DOM, 0, 0)
#define M4U_PORT_L0_OVL_RDMA0_HDR		MTK_M4U_PORT_ID(MM_TAB, NORMAL_DOM, 0, 1)
#define M4U_PORT_L0_OVL_RDMA0			MTK_M4U_PORT_ID(MM_TAB, NORMAL_DOM, 0, 2)
#define M4U_PORT_L0_DISP_FAKE0			MTK_M4U_PORT_ID(MM_TAB, NORMAL_DOM, 0, 3)
/* larb1 -- 5 */
#define M4U_PORT_L1_OVL_2L_RDMA0_HDR		MTK_M4U_PORT_ID(MM_TAB, NORMAL_DOM, 1, 0)
#define M4U_PORT_L1_OVL_2L_RDMA0		MTK_M4U_PORT_ID(MM_TAB, NORMAL_DOM, 1, 1)
#define M4U_PORT_L1_DISP_RDMA0			MTK_M4U_PORT_ID(MM_TAB, NORMAL_DOM, 1, 2)
#define M4U_PORT_L1_DISP_WDMA0			MTK_M4U_PORT_ID(MM_TAB, NORMAL_DOM, 1, 3)
#define M4U_PORT_L1_DISP_FAKE1			MTK_M4U_PORT_ID(MM_TAB, NORMAL_DOM, 1, 4)
/* larb2 -- 5 */
#define M4U_PORT_L2_MDP_RDMA0			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 2, 0)
#define M4U_PORT_L2_MDP_RDMA1			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 2, 1)
#define M4U_PORT_L2_MDP_WROT0			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 2, 2)
#define M4U_PORT_L2_MDP_WROT1			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 2, 3)
#define M4U_PORT_L2_MDP_DISP_FAKE0		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 2, 4)
/* larb3 -- null */
/* larb4 -- 14 */
#define M4U_PORT_L4_VDEC_MC_EXT			MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 4, 0)
#define M4U_PORT_L4_VDEC_UFO_EXT		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 4, 1)
#define M4U_PORT_L4_VDEC_PP_EXT			MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 4, 2)
#define M4U_PORT_L4_VDEC_PRED_RD_EXT		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 4, 3)
#define M4U_PORT_L4_VDEC_PRED_WR_EXT		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 4, 4)
#define M4U_PORT_L4_VDEC_PPWRAP_EXT		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 4, 5)
#define M4U_PORT_L4_VDEC_TILE_EXT		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 4, 6)
#define M4U_PORT_L4_VDEC_VLD_EXT		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 4, 7)
#define M4U_PORT_L4_VDEC_VLD2_EXT		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 4, 8)
#define M4U_PORT_L4_VDEC_AVC_MV_EXT		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 4, 9)
#define M4U_PORT_L4_VDEC_UFO_ENC_EXT		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 4, 10)
#define M4U_PORT_L4_VDEC_RG_CTRL_DMA_EXT	MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 4, 11)
#define M4U_PORT_L4_MINI_MDP_R0_EXT		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 4, 12)
#define M4U_PORT_L4_MINI_MDP_W0_EXT		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 4, 13)
/* larb5 -- null */
/* larb6 -- null */
/* larb7 -- 13 */
#define M4U_PORT_L7_VENC_RCPU			MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 7, 0)
#define M4U_PORT_L7_VENC_REC			MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 7, 1)
#define M4U_PORT_L7_VENC_BSDMA			MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 7, 2)
#define M4U_PORT_L7_VENC_SV_COMV		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 7, 3)
#define M4U_PORT_L7_VENC_RD_COMV		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 7, 4)
#define M4U_PORT_L7_VENC_CUR_LUMA		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 7, 5)
#define M4U_PORT_L7_VENC_CUR_CHROMA		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 7, 6)
#define M4U_PORT_L7_VENC_REF_LUMA		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 7, 7)
#define M4U_PORT_L7_VENC_REF_CHROMA		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 7, 8)
#define M4U_PORT_L7_JPGENC_Y_RDMA		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 7, 9)
#define M4U_PORT_L7_JPGENC_C_RDMA		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 7, 10)
#define M4U_PORT_L7_JPGENC_Q_TABLE		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 7, 11)
#define M4U_PORT_L7_JPGENC_BSDMA		MTK_M4U_PORT_ID(MM_TAB, VDEC_DOM, 7, 12)
/* larb8 -- null */
/* larb9 -- 29 */
/* port0~port14 is used, port15~port28 is not used */
#define M4U_PORT_L9_IMG_IMGI_D1			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 0)
#define M4U_PORT_L9_IMG_IMGBI_D1		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 1)
#define M4U_PORT_L9_IMG_DMGI_D1			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 2)
#define M4U_PORT_L9_IMG_DEPI_D1			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 3)
#define M4U_PORT_L9_IMG_ICE_D1			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 4)
#define M4U_PORT_L9_IMG_SMTI_D1			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 5)
#define M4U_PORT_L9_IMG_SMTO_D2			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 6)
#define M4U_PORT_L9_IMG_SMTO_D1			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 7)
#define M4U_PORT_L9_IMG_CRZO_D1			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 8)
#define M4U_PORT_L9_IMG_IMG3O_D1		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 9)
#define M4U_PORT_L9_IMG_VIPI_D1			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 10)
#define M4U_PORT_L9_IMG_SMTI_D5			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 11)
#define M4U_PORT_L9_IMG_TIMGO_D1		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 12)
#define M4U_PORT_L9_IMG_UFBC_W0			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 13)
#define M4U_PORT_L9_IMG_UFBC_R0			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 14)
#define M4U_PORT_L9_IMG_WPE_RDMA1		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 15)
#define M4U_PORT_L9_IMG_WPE_RDMA0		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 16)
#define M4U_PORT_L9_IMG_WPE_WDMA		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 17)
#define M4U_PORT_L9_IMG_MFB_RDMA0		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 18)
#define M4U_PORT_L9_IMG_MFB_RDMA1		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 19)
#define M4U_PORT_L9_IMG_MFB_RDMA2		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 20)
#define M4U_PORT_L9_IMG_MFB_RDMA3		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 21)
#define M4U_PORT_L9_IMG_MFB_RDMA4		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 22)
#define M4U_PORT_L9_IMG_MFB_RDMA5		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 23)
#define M4U_PORT_L9_IMG_MFB_WDMA0		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 24)
#define M4U_PORT_L9_IMG_MFB_WDMA1		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 25)
#define M4U_PORT_L9_IMG_RESERVE6		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 26)
#define M4U_PORT_L9_IMG_RESERVE7		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 27)
#define M4U_PORT_L9_IMG_RESERVE8		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 9, 28)
/* larb10 -- null */
/* larb11 -- null */
/* larb12 -- null */
/* larb13 -- 12 */
#define M4U_PORT_L13_CAM_MRAWI			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 13, 0)
#define M4U_PORT_L13_CAM_MRAWO0			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 13, 1)
#define M4U_PORT_L13_CAM_MRAWO1			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 13, 2)
#define M4U_PORT_L13_CAM_RESERVE1		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 13, 3)
#define M4U_PORT_L13_CAM_RESERVE2		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 13, 4)
#define M4U_PORT_L13_CAM_RESERVE3		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 13, 5)
#define M4U_PORT_L13_CAM_CAMSV4			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 13, 6)
#define M4U_PORT_L13_CAM_CAMSV5			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 13, 7)
#define M4U_PORT_L13_CAM_CAMSV6			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 13, 8)
#define M4U_PORT_L13_CAM_CCUI			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 13, 9)
#define M4U_PORT_L13_CAM_CCUO			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 13, 10)
#define M4U_PORT_L13_CAM_FAKE			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 13, 11)
/* larb14 -- 6 */
#define M4U_PORT_L14_CAM_RESERVE1		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 14, 0)
#define M4U_PORT_L14_CAM_RESERVE2		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 14, 1)
#define M4U_PORT_L14_CAM_RESERVE3		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 14, 2)
#define M4U_PORT_L14_CAM_RESERVE4		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 14, 3)
#define M4U_PORT_L14_CAM_CCUI			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 14, 4)
#define M4U_PORT_L14_CAM_CCUO			MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 14, 5)
/* larb15 -- null */
/* larb16 -- 17 */
#define M4U_PORT_L16_CAM_IMGO_R1_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 0)
#define M4U_PORT_L16_CAM_RRZO_R1_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 1)
#define M4U_PORT_L16_CAM_CQI_R1_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 2)
#define M4U_PORT_L16_CAM_BPCI_R1_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 3)
#define M4U_PORT_L16_CAM_YUVO_R1_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 4)
#define M4U_PORT_L16_CAM_UFDI_R2_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 5)
#define M4U_PORT_L16_CAM_RAWI_R2_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 6)
#define M4U_PORT_L16_CAM_RAWI_R3_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 7)
#define M4U_PORT_L16_CAM_AAO_R1_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 8)
#define M4U_PORT_L16_CAM_AFO_R1_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 9)
#define M4U_PORT_L16_CAM_FLKO_R1_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 10)
#define M4U_PORT_L16_CAM_LCESO_R1_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 11)
#define M4U_PORT_L16_CAM_CRZO_R1_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 12)
#define M4U_PORT_L16_CAM_LTMSO_R1_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 13)
#define M4U_PORT_L16_CAM_RSSO_R1_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 14)
#define M4U_PORT_L16_CAM_AAHO_R1_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 15)
#define M4U_PORT_L16_CAM_LSCI_R1_A		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 16, 16)
/* larb17 -- 17 */
#define M4U_PORT_L17_CAM_IMGO_R1_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 0)
#define M4U_PORT_L17_CAM_RRZO_R1_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 1)
#define M4U_PORT_L17_CAM_CQI_R1_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 2)
#define M4U_PORT_L17_CAM_BPCI_R1_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 3)
#define M4U_PORT_L17_CAM_YUVO_R1_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 4)
#define M4U_PORT_L17_CAM_UFDI_R2_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 5)
#define M4U_PORT_L17_CAM_RAWI_R2_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 6)
#define M4U_PORT_L17_CAM_RAWI_R3_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 7)
#define M4U_PORT_L17_CAM_AAO_R1_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 8)
#define M4U_PORT_L17_CAM_AFO_R1_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 9)
#define M4U_PORT_L17_CAM_FLKO_R1_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 10)
#define M4U_PORT_L17_CAM_LCESO_R1_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 11)
#define M4U_PORT_L17_CAM_CRZO_R1_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 12)
#define M4U_PORT_L17_CAM_LTMSO_R1_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 13)
#define M4U_PORT_L17_CAM_RSSO_R1_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 14)
#define M4U_PORT_L17_CAM_AAHO_R1_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 15)
#define M4U_PORT_L17_CAM_LSCI_R1_B		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 17, 16)
/* larb18 -- null */
/* larb19 -- 4 */
#define M4U_PORT_L19_IPE_DVS_RDMA		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 19, 0)
#define M4U_PORT_L19_IPE_DVS_WDMA		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 19, 1)
#define M4U_PORT_L19_IPE_DVP_RDMA		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 19, 2)
#define M4U_PORT_L19_IPE_DVP_WDMA		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 19, 3)
/* larb20 -- 6 */
#define M4U_PORT_L20_IPE_FDVT_RDA		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 20, 0)
#define M4U_PORT_L20_IPE_FDVT_RDB		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 20, 1)
#define M4U_PORT_L20_IPE_FDVT_WRA		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 20, 2)
#define M4U_PORT_L20_IPE_FDVT_WRB		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 20, 3)
#define M4U_PORT_L20_IPE_RSC_RDMA0		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 20, 4)
#define M4U_PORT_L20_IPE_RSC_WDMA		MTK_M4U_PORT_ID(MM_TAB, CAMMDP_DOM, 20, 5)

#endif
