/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Copyright (c) 2021 MediaTek Inc.
 */

#ifndef __MFD_MT6366_CORE_H__
#define __MFD_MT6366_CORE_H__

enum mt6366_irq_top_status_shift {
	MT6366_BUCK_TOP = 0,
	MT6366_LDO_TOP,
	MT6366_PSC_TOP,
	MT6366_SCK_TOP,
	MT6366_BM_TOP,
	MT6366_HK_TOP,
	MT6366_AUD_TOP = 7,
	MT6366_MISC_TOP,
};

enum mt6366_irq_numbers {
	MT6366_IRQ_VPROC11_OC = 0,
	MT6366_IRQ_VPROC12_OC,
	MT6366_IRQ_VCORE_OC,
	MT6366_IRQ_VGPU_OC,
	MT6366_IRQ_VMODEM_OC,
	MT6366_IRQ_VDRAM1_OC,
	MT6366_IRQ_VS1_OC,
	MT6366_IRQ_VS2_OC,
	MT6366_IRQ_VPA_OC,
	MT6366_IRQ_VCORE_PREOC,
	MT6366_IRQ_VFE28_OC = 16,
	MT6366_IRQ_VXO22_OC,
	MT6366_IRQ_VRF18_OC,
	MT6366_IRQ_VRF12_OC,
	MT6366_IRQ_VEFUSE_OC,
	MT6366_IRQ_VCN33_OC,
	MT6366_IRQ_VCN28_OC,
	MT6366_IRQ_VCN18_OC,
	MT6366_IRQ_VM18_OC,
	MT6366_IRQ_VMDDR_OC,
	MT6366_IRQ_VSRAM_CORE_OC,
	MT6366_IRQ_VA12_OC = 29,
	MT6366_IRQ_VAUX18_OC,
	MT6366_IRQ_VAUD28_OC,
	MT6366_IRQ_VIO28_OC,
	MT6366_IRQ_VIO18_OC,
	MT6366_IRQ_VSRAM_PROC11_OC,
	MT6366_IRQ_VSRAM_PROC12_OC,
	MT6366_IRQ_VSRAM_OTHERS_OC,
	MT6366_IRQ_VSRAM_GPU_OC,
	MT6366_IRQ_VDRAM2_OC,
	MT6366_IRQ_VMC_OC,
	MT6366_IRQ_VMCH_OC,
	MT6366_IRQ_VEMC_OC,
	MT6366_IRQ_VSIM1_OC,
	MT6366_IRQ_VSIM2_OC,
	MT6366_IRQ_VIBR_OC,
	MT6366_IRQ_VUSB_OC,
	MT6366_IRQ_VBIF28_OC,
	MT6366_IRQ_PWRKEY = 48,
	MT6366_IRQ_HOMEKEY,
	MT6366_IRQ_PWRKEY_R,
	MT6366_IRQ_HOMEKEY_R,
	MT6366_IRQ_NI_LBAT_INT,
	MT6366_IRQ_CHRDET,
	MT6366_IRQ_CHRDET_EDGE,
	MT6366_IRQ_VCDT_HV_DET,
	MT6366_IRQ_RTC = 64,
	MT6366_IRQ_FG_BAT0_H = 80,
	MT6366_IRQ_FG_BAT0_L,
	MT6366_IRQ_FG_CUR_H,
	MT6366_IRQ_FG_CUR_L,
	MT6366_IRQ_FG_ZCV,
	MT6366_IRQ_FG_BAT1_H,
	MT6366_IRQ_FG_BAT1_L,
	MT6366_IRQ_FG_N_CHARGE_L,
	MT6366_IRQ_FG_IAVG_H,
	MT6366_IRQ_FG_IAVG_L,
	MT6366_IRQ_FG_TIME_H,
	MT6366_IRQ_FG_DISCHARGE,
	MT6366_IRQ_FG_CHARGE,
	MT6366_IRQ_BATON_LV = 96,
	MT6366_IRQ_BATON_HT,
	MT6366_IRQ_BATON_BAT_IN,
	MT6366_IRQ_BATON_BAT_OUT,
	MT6366_IRQ_BIF,
	MT6366_IRQ_BAT_H = 112,
	MT6366_IRQ_BAT_L,
	MT6366_IRQ_BAT2_H,
	MT6366_IRQ_BAT2_L,
	MT6366_IRQ_BAT_TEMP_H,
	MT6366_IRQ_BAT_TEMP_L,
	MT6366_IRQ_AUXADC_IMP,
	MT6366_IRQ_NAG_C_DLTV,
	MT6366_IRQ_AUDIO = 128,
	MT6366_IRQ_ACCDET = 133,
	MT6366_IRQ_ACCDET_EINT0,
	MT6366_IRQ_ACCDET_EINT1,
	MT6366_IRQ_SPI_CMD_ALERT = 144,
	MT6366_IRQ_NR,
};

#define MT6366_IRQ_BUCK_BASE MT6366_IRQ_VPROC11_OC
#define MT6366_IRQ_LDO_BASE MT6366_IRQ_VFE28_OC
#define MT6366_IRQ_PSC_BASE MT6366_IRQ_PWRKEY
#define MT6366_IRQ_SCK_BASE MT6366_IRQ_RTC
#define MT6366_IRQ_BM_BASE MT6366_IRQ_FG_BAT0_H
#define MT6366_IRQ_HK_BASE MT6366_IRQ_BAT_H
#define MT6366_IRQ_AUD_BASE MT6366_IRQ_AUDIO
#define MT6366_IRQ_MISC_BASE MT6366_IRQ_SPI_CMD_ALERT

#define MT6366_IRQ_BUCK_BITS (MT6366_IRQ_VCORE_PREOC - MT6366_IRQ_BUCK_BASE + 1)
#define MT6366_IRQ_LDO_BITS (MT6366_IRQ_VBIF28_OC - MT6366_IRQ_LDO_BASE + 1)
#define MT6366_IRQ_PSC_BITS (MT6366_IRQ_VCDT_HV_DET - MT6366_IRQ_PSC_BASE + 1)
#define MT6366_IRQ_SCK_BITS (MT6366_IRQ_RTC - MT6366_IRQ_SCK_BASE + 1)
#define MT6366_IRQ_BM_BITS (MT6366_IRQ_BIF - MT6366_IRQ_BM_BASE + 1)
#define MT6366_IRQ_HK_BITS (MT6366_IRQ_NAG_C_DLTV - MT6366_IRQ_HK_BASE + 1)
#define MT6366_IRQ_AUD_BITS (MT6366_IRQ_ACCDET_EINT1 - MT6366_IRQ_AUD_BASE + 1)
#define MT6366_IRQ_MISC_BITS (MT6366_IRQ_SPI_CMD_ALERT - MT6366_IRQ_MISC_BASE + 1)

#define MT6366_TOP_GEN(sp)	\
{	\
	.hwirq_base = MT6366_IRQ_##sp##_BASE,	\
	.num_int_regs =	\
		((MT6366_IRQ_##sp##_BITS - 1) /	\
		MTK_PMIC_REG_WIDTH) + 1,	\
	.en_reg = MT6358_##sp##_TOP_INT_CON0,	\
	.en_reg_shift = 0x6,	\
	.sta_reg = MT6358_##sp##_TOP_INT_STATUS0,	\
	.sta_reg_shift = 0x2,	\
	.top_offset = MT6366_##sp##_TOP,	\
}

#endif /* __MFD_MT6366_CORE_H__ */
